@@ -5,7 +5,8 @@ from zope.component import getMultiAdapter
 from zope.i18nmessageid import MessageFactory
 from zope.schema import ValidationError
 
-_ = MessageFactory('plone.formwidget.recaptcha')
+
+_ = MessageFactory("plone.formwidget.recaptcha")
 
 
 class WrongCaptchaCode(ValidationError):
@@ -13,12 +14,10 @@ class WrongCaptchaCode(ValidationError):
 
 
 class ReCaptchaValidator(validator.SimpleFieldValidator):
-
     def validate(self, value):
         super(ReCaptchaValidator, self).validate(value)
         captcha = getMultiAdapter(
-            (aq_inner(self.context), self.request),
-            name='recaptcha'
+            (aq_inner(self.context), self.request), name="recaptcha"
         )
         if not captcha.verify():
             raise WrongCaptchaCode
